@@ -88,7 +88,7 @@ class Template:
         """Returns its annotated type given a PDF form element."""
 
         element_type_mapping = {
-            "/Btn": "MULTIPLE",
+            "/Btn": ElementType.checkbox,
             "/Tx": ElementType.text,
         }
 
@@ -96,12 +96,6 @@ class Template:
             str(element[TemplateCoreConstants().element_type_key])
         )
 
-        if result == "MULTIPLE":
-            if element[TemplateCoreConstants().checkbox_field_value_key]:
-                return ElementType.checkbox
-            else:
-                return ElementType.image
-
         if not result and element[TemplateCoreConstants().radio_button_group_key]:
             return ElementType.radio
 
@@ -123,30 +117,6 @@ class Template:
             - 2,
         )
 
-    @staticmethod
-    def get_draw_image_coordinates(
-        element: "pdfrw.PdfDict",
-    ) -> Tuple[Union[float, int], Union[float, int]]:
-        """Returns coordinates to draw image at given a PDF form image element."""
-
-        return (
-            float(element[TemplateCoreConstants().annotation_rectangle_key][0]),
-            float(element[TemplateCoreConstants().annotation_rectangle_key][1]),
-        )
-
-    @staticmethod
-    def get_draw_image_resolutions(
-        element: "pdfrw.PdfDict",
-    ) -> Tuple[Union[float, int], Union[float, int]]:
-        """Returns width and height of the image given a PDF form image element."""
-
-        return (
-            float(element[TemplateCoreConstants().annotation_rectangle_key][2])
-            - float(element[TemplateCoreConstants().annotation_rectangle_key][0]),
-            float(element[TemplateCoreConstants().annotation_rectangle_key][3])
-            - float(element[TemplateCoreConstants().annotation_rectangle_key][1]),
-        )
-
     def assign_uuid(self, pdf: bytes) -> bytes:
         """Appends a separator and uuid after each element's annotated name."""
 
