@@ -27,7 +27,7 @@ class Utils:
 
     @staticmethod
     def bool_to_checkboxes(
-        data: Dict[str, Union[str, bool, bytes, int]]
+        data: Dict[str, Union[str, bool, int]]
     ) -> Dict[str, Union[str, "pdfrw.PdfName"]]:
         """Converts all boolean values in input data dictionary into PDF checkbox objects."""
 
